synthetic package — src documentation

# synthetic package

## Subpackages

- synthetic.fetch_data package
  - Submodules
  - synthetic.fetch_data.adult module
  - synthetic.fetch_data.split module
  - synthetic.fetch_data.utk module
  - Module contents
- synthetic.generator package
  - Submodules
  - synthetic.generator.example module
  - Module contents
- synthetic.predictor package
  - Submodules
  - synthetic.predictor.adult module
  - Module contents

## Module contents